.. os-doc-demo documentation master file, created by
   sphinx-quickstart on Tue Jan 20 08:22:27 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Demo documentation
==================

The project is an open source cloud computing platform that supports all types
of cloud environments.

The project aims for simple implementation, massive scalability, and a rich set
of features. Cloud computing experts from around the world contribute to the project.

Here's an example configuration::
[DEFAULT]
...
my_ip = 10.0.0.31
vnc_enabled = True
vncserver_listen = 0.0.0.0
vncserver_proxyclient_address = 10.0.0.31
novncproxy_base_url = http://controller:6080/vnc_auto.html

..note:: Here's an example note.

Developer Guide
===============

Information on Nova's lower level programming APIs.
